pub struct ExportService { /* private fields */ }Expand description
Implements a client for the Cloud Profiler API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = ExportService::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_profiles()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Service allows existing Cloud Profiler customers to export their profile data out of Google Cloud.
Configuration
To configure ExportService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://cloudprofiler.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
ExportService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap ExportService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl ExportService
impl ExportService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for ExportService.
let client = ExportService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: ExportService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: ExportService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_profiles(&self) -> ListProfiles
pub fn list_profiles(&self) -> ListProfiles
Lists profiles which have been collected so far and for which the caller has permission to view.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_profiler_v2::Result;
async fn sample(
client: &ExportService, parent: &str
) -> Result<()> {
let mut list = client.list_profiles()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Trait Implementations
Sourceimpl Clone for ExportService
impl Clone for ExportService
Sourcefn clone(&self) -> ExportService
fn clone(&self) -> ExportService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more